## Video

<webc-container>
    <webc-video title="an video" width="100%" height="100px" url="https://470426667096-cbr.s3.eu-west-2.amazonaws.com/cbr_website_static/assets/videos/video-tcb__introduction__27-feb-2024.mp4"> 
    </webc-video>
    <webc-api-markdown-to-html content_path='en/web-pages/demos/index.md'></webc-api-markdown-to-html>
    <webc-video title="an video" width="100%" height="200px"url="https://470426667096-cbr.s3.eu-west-2.amazonaws.com/cbr_website_static/assets/videos/video-tcb__introduction__27-feb-2024.mp4"> 
    </webc-video> 
</webc-container>

<webc-container>
    <webc-video title="an video" 
            width="100%" 
            height="100px" 
            url="https://470426667096-cbr.s3.eu-west-2.amazonaws.com/cbr_website_static/assets/videos/video-tcb__introduction__27-feb-2024.mp4"> 
    </webc-video>
</webc-container>



